Package: MBNMAdose
Type: Package
Title: Dose-Response MBNMA Models
Version: 0.5.0
Language: en-GB
Date: 2025-02-06
Authors@R: c(person("Hugo", "Pedder", 
        email = "hugopedder@gmail.com", 
        role = c("aut", "cre"), 
        comment = c(ORCID = "0000-0002-7813-3749")),
    person("Adil", "Karim", role = c("ctb")))
URL: https://hugaped.github.io/MBNMAdose/
Maintainer: Hugo Pedder <hugopedder@gmail.com>
Description: Fits Bayesian dose-response model-based network meta-analysis (MBNMA) 
    that incorporate multiple doses within an agent by modelling different dose-response functions, as
    described by Mawdsley et al. (2016) <doi:10.1002/psp4.12091>. 
    By modelling dose-response relationships this can connect networks of evidence that might
    otherwise be disconnected, and can improve precision on treatment estimates. Several common 
    dose-response functions are provided; others may be added by the user. Various characteristics
    and assumptions can be flexibly added to the models, such as shared class effects. The consistency 
    of direct and indirect evidence in the network can be assessed using unrelated mean effects models 
    and/or by node-splitting at the treatment level.
License: GPL-3
Depends: R (>= 3.0.2)
Imports: grDevices, stats, graphics, utils, scales, dplyr (>= 0.7.4),
        R2jags (>= 0.5-7), rjags (>= 4-8), magrittr (>= 1.5), checkmate
        (>= 1.8.5), Rdpack (>= 0.11-0), igraph (>= 2.0.1.1), ggplot2
        (>= 2.2.1), reshape2 (>= 1.4.3)
Suggests: overlapping (>= 1.5.0), RColorBrewer (>= 1.1-2), mcmcplots
        (>= 0.4.3), coda (>= 0.19-4), testthat (>= 1.0.2), crayon (>=
        1.3.4), forestplot (>= 1.10), ggdist (>= 2.4.0), zoo (>=
        1.8-8), lspline (>= 1.0-0), formatR (>= 1.14), netmeta, knitr,
        rmarkdown
SystemRequirements: JAGS (>= 4.3.0)
        (https://mcmc-jags.sourceforge.net/)
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 7.2.3
RdMacros: Rdpack
NeedsCompilation: no
Packaged: 2025-02-06 19:58:33 UTC; hp17602
Author: Hugo Pedder [aut, cre] (<https://orcid.org/0000-0002-7813-3749>),
  Adil Karim [ctb]
Repository: CRAN
Date/Publication: 2025-02-07 00:40:23 UTC
Built: R 4.3.3; ; 2025-02-15 08:05:28 UTC; unix
