# Generated by roxygen2: do not edit by hand

S3method(plot,mbnma)
S3method(plot,mbnma.network)
S3method(plot,mbnma.predict)
S3method(plot,mbnma.rank)
S3method(plot,nma)
S3method(plot,nma.nodesplit)
S3method(plot,nodesplit)
S3method(predict,mbnma)
S3method(print,mbnma.network)
S3method(print,mbnma.predict)
S3method(print,mbnma.rank)
S3method(print,nma.nodesplit)
S3method(print,nodesplit)
S3method(print,relative.array)
S3method(rank,mbnma)
S3method(rank,mbnma.predict)
S3method(rank,relative.array)
S3method(summary,mbnma)
S3method(summary,mbnma.network)
S3method(summary,mbnma.predict)
S3method(summary,mbnma.rank)
S3method(summary,nma.nodesplit)
S3method(summary,nodesplit)
export("%>%")
export(calc.edx)
export(cumrank)
export(default.priors)
export(demax)
export(devdev)
export(devplot)
export(dexp)
export(dfpoly)
export(ditp)
export(dloglin)
export(dmulti)
export(dnonparam)
export(dpoly)
export(drop.disconnected)
export(dspline)
export(duser)
export(fitplot)
export(genspline)
export(get.prior)
export(get.relative)
export(getjagsdata)
export(inconsistency.loops)
export(mbnma.comparisons)
export(mbnma.network)
export(mbnma.nodesplit)
export(mbnma.run)
export(mbnma.update)
export(mbnma.write)
export(nma.nodesplit)
export(nma.run)
export(norm2lnorm)
export(pDcalc)
export(rank)
export(ref.synth)
export(rescale.link)
importFrom(Rdpack,reprompt)
importFrom(magrittr,"%>%")
